summaryrefslogtreecommitdiff
path: root/src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs
diff options
context:
space:
mode:
Diffstat (limited to 'src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs')
-rw-r--r--src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs b/src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs
index d84671ee..b8f2c34e 100644
--- a/src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs
+++ b/src/StardewModdingAPI/Framework/Logging/ConsoleInterceptionManager.cs
@@ -18,8 +18,8 @@ namespace StardewModdingAPI.Framework.Logging
/// <summary>Whether the current console supports color formatting.</summary>
public bool SupportsColor { get; }
- /// <summary>The event raised when something writes a line to the console directly.</summary>
- public event Action<string> OnLineIntercepted;
+ /// <summary>The event raised when a message is written to the console directly.</summary>
+ public event Action<string> OnMessageIntercepted;
/*********
@@ -30,7 +30,7 @@ namespace StardewModdingAPI.Framework.Logging
{
// redirect output through interceptor
this.Output = new InterceptingTextWriter(Console.Out);
- this.Output.OnLineIntercepted += line => this.OnLineIntercepted?.Invoke(line);
+ this.Output.OnMessageIntercepted += line => this.OnMessageIntercepted?.Invoke(line);
Console.SetOut(this.Output);
// test color support